@@ -11,7 +11,7 @@ NAME = __name__.split('.')[-1] # package name (e.g. 'foo' or 'foo_bar')
                                # please use a all-lowercase valid python
                                # package name
 
-VERSION = '1.12.0' # version of the packaged files, please use the upstream
+VERSION = '1.12.1' # version of the packaged files, please use the upstream
                    # version number
 BUILD = '1'  # our package build number, so we can release new builds
              # with fixes for xstatic stuff.
@@ -28,7 +28,7 @@ MAINTAINER = 'Thomas Waldmann'
 MAINTAINER_EMAIL = 'tw@waldmann-edv.de'
 
 # this refers to the project homepage of the stuff we packaged:
-HOMEPAGE = 'http://jqueryui.com/'
+HOMEPAGE = 'https://jqueryui.com/'
 
 # this refers to all files:
 LICENSE = '(same as %s)' % DISPLAY_NAME
